@@ -26,7 +26,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 
 # Preloaded methods go here.
@@ -39,14 +39,19 @@ __END__
 
 =head1 NAME
 
-GFX-Tools - several command line graphics tools  
+GFX-Tools - several command line graphics tools, based on GFX-Tools-Buffer.  
 
 =head1 SYNOPSIS
 
-  use GFX-Tools;
+  use GFX::Tools;
 
 =head1 DESCRIPTION
 
+The meaning is to have a filter system which changes your graphics files in any
+way. Most things are PNG oriented (an open source file format), there are 
+examples included which you can base your own code on or design a filter with
+the codebase.
+
 =head2 EXPORT
 
 =head1 SEE ALSO
